Class: Peddler::APIs::ExternalFulfillmentShipments20240911::PackageShipLabelList

Inherits:
Array
  • Object
show all
Defined in:
lib/peddler/apis/external_fulfillment_shipments_2024_09_11/package_ship_label_list.rb

Overview

A list of label documents for each package specified in the request. In case of partial failures when generating labels, the ‘isErrored` and `errorDetails` attributes detail the cause of failure.

Class Method Summary collapse

Class Method Details

.parse(array) ⇒ Object



12
13
14
# File 'lib/peddler/apis/external_fulfillment_shipments_2024_09_11/package_ship_label_list.rb', line 12

def parse(array)
  new(array.map { |item| PackageShipLabel.parse(item) })
end